pyparsing.pyparsing.ParseSyntaxException

Package pyparsing :: Module pyparsing :: Class ParseSyntaxException |
[frames] | no frames]

# Class ParseSyntaxException

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                  ParseBaseException --+
                                       |
                     ParseFatalException --+
                                           |
                                          ParseSyntaxException

just like ParseFatalException, but thrown internally when an ErrorStop indicates that parsing is to stop immediately because an unbacktrackable syntax error has been found

Instance Methods
__init__(self, pe) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `ParseBaseException`: `__getattr__`, `__repr__`, `__str__`, `markInputline` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties
Inherited from `ParseBaseException`: `loc`, `msg`, `parserElement`, `pstr` Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, pe) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)